==> pipewire-docs-1%3A0.3.34-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/impl-device_8c.js <==
var impl_device_8c =
[
    [ "impl", "structimpl.html", "structimpl" ],
    [ "result_device_params_data", "structresult__device__params__data.html", "structresult__device__params__data" ],
    [ "resource_data", "structresource__data.html", "structresource__data" ],
    [ "object_data", "structobject__data.html", "structobject__data" ],
    [ "NAME", "impl-device_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "OBJECT_DEVICE", "impl-device_8c.html#a852ab8a73838fe0cb210cf1008258495", null ],
    [ "OBJECT_NODE", "impl-device_8c.html#ac7b48ba8f638896c1af21130874f8927", null ],
    [ "pw_device_resource", "impl-device_8c.html#a2d5055c2bde5156b9733e2c05707ce1d", null ],
    [ "pw_device_resource_info", "impl-device_8c.html#a0528b4bcf35918c8c27fc794e66b892a", null ],
    [ "pw_device_resource_param", "impl-device_8c.html#a94d16ebbb03910ad19fa6ef94eb0278d", null ],
    [ "pw_context_create_device", "group__pw__impl__device.html#ga78eb429fee1c1fc1ee0e0afe3e7b82db", null ],
    [ "pw_impl_device_add_listener", "group__pw__impl__device.html#ga8365dd9ac6c4cc731cbc7bcbd5a68c8a", null ],
    [ "pw_impl_device_destroy", "group__pw__impl__device.html#ga206bef1c4398d878a95dac034d008cb9", null ],
    [ "pw_impl_device_for_each_param", "group__pw__impl__device.html#gab94fa183d46cce3606c559ca10df16ce", null ],
    [ "pw_impl_device_get_global", "group__pw__impl__device.html#ga379149ca6d9af076d83a4138de3a40b4", null ],
    [ "pw_impl_device_get_implementation", "group__pw__impl__device.html#ga5604f577ad7269e874640dda9ca5431b", null ],
    [ "pw_impl_device_get_properties", "group__pw__impl__device.html#gafe06faa61770c9a9d23e4aa51fea3dec", null ],
    [ "pw_impl_device_get_user_data", "group__pw__impl__device.html#ga17868c55b21c5977354b2a4cee8036e9", null ],
    [ "pw_impl_device_register", "group__pw__impl__device.html#ga5ad9e42ea1d048840b5ef3785ff5034d", null ],
    [ "pw_impl_device_set_implementation", "group__pw__impl__device.html#ga231905eac744e7eeae3512c6e90a5079", null ],
    [ "pw_impl_device_update_properties", "group__pw__impl__device.html#gadde284a435764d784c07179253f01b7a", null ]
];

==> pipewire-docs-1%3A0.3.38-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/impl-device_8c.js <==
var impl_device_8c =
[
    [ "impl", "structimpl.html", "structimpl" ],
    [ "result_device_params_data", "structresult__device__params__data.html", "structresult__device__params__data" ],
    [ "resource_data", "structresource__data.html", "structresource__data" ],
    [ "object_data", "structobject__data.html", "structobject__data" ],
    [ "OBJECT_DEVICE", "impl-device_8c.html#a852ab8a73838fe0cb210cf1008258495", null ],
    [ "OBJECT_NODE", "impl-device_8c.html#ac7b48ba8f638896c1af21130874f8927", null ],
    [ "pw_device_resource", "impl-device_8c.html#a2d5055c2bde5156b9733e2c05707ce1d", null ],
    [ "pw_device_resource_info", "impl-device_8c.html#a0528b4bcf35918c8c27fc794e66b892a", null ],
    [ "pw_device_resource_param", "impl-device_8c.html#a94d16ebbb03910ad19fa6ef94eb0278d", null ],
    [ "PW_LOG_TOPIC_DEFAULT", "impl-device_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
    [ "pw_context_create_device", "group__pw__impl__device.html#gaf7a2385c66b42b5a5a48a53999c05ac8", null ],
    [ "pw_impl_device_add_listener", "group__pw__impl__device.html#ga8365dd9ac6c4cc731cbc7bcbd5a68c8a", null ],
    [ "pw_impl_device_destroy", "group__pw__impl__device.html#ga206bef1c4398d878a95dac034d008cb9", null ],
    [ "pw_impl_device_for_each_param", "group__pw__impl__device.html#gab94fa183d46cce3606c559ca10df16ce", null ],
    [ "pw_impl_device_get_global", "group__pw__impl__device.html#gaa2740ec45018e6799a0ff92d12fe7c97", null ],
    [ "pw_impl_device_get_implementation", "group__pw__impl__device.html#ga216a66f5646678bdeb761ccdecc530b2", null ],
    [ "pw_impl_device_get_properties", "group__pw__impl__device.html#ga2786a192d34aa5b9901543cd677e48d7", null ],
    [ "pw_impl_device_get_user_data", "group__pw__impl__device.html#ga0b276d268df05641e6835facbbaa3c48", null ],
    [ "pw_impl_device_register", "group__pw__impl__device.html#ga5ad9e42ea1d048840b5ef3785ff5034d", null ],
    [ "pw_impl_device_set_implementation", "group__pw__impl__device.html#ga231905eac744e7eeae3512c6e90a5079", null ],
    [ "pw_impl_device_update_properties", "group__pw__impl__device.html#gadde284a435764d784c07179253f01b7a", null ],
    [ "PW_LOG_TOPIC_EXTERN", "impl-device_8c.html#aaf5e71d40c70d2aca609d2e96ef568ad", null ]
];
